==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S545833936c4079bf95b16d8fea1c7133.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S545833936c4079bf95b16d8fea1c7133.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S8e72db935b8a34033901bc251e070387.h"

#include "Sc9fab33e9458412c527c3fe8a13ee37d.h"

#if Sa06671aa7d7bca0d64f1e6a1a3d29941
 
#if HAVE_STRINGS_H
 
#include <strings.h>

#endif
 
#endif
 
#if HAVE_UNISTD_H
 
#include <unistd.h>

#endif
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#if HAVE_SYS_SOCKET_H
 
#include <sys/socket.h>

#endif
 
#if HAVE_NETINET_IN_H
 
#include <netinet/in.h>

#endif
 
#if S63cf4d813c4c3f398df1ae89db2b63a1
 
#include <fcntl.h>

#endif
 
#if HAVE_SYS_TIME_H
 
#include <sys/time.h>

#endif
 
#if HAVE_NETDB_H
 
#include <netdb.h>

#endif
 
#if HAVE_ARPA_INET_H
 
#include <arpa/inet.h>

#endif
 
#ifdef WIN32
 
# include <winsock.h>

#endif
 
#if !HAS_BZERO
 
#define Sc19e6f17145de2e8f33ebc0b4ecd0965(S03c7c0ace395d80182db07ae2c30f034, S7b8b965ad4bca0e41ab51de7b31363a1)	memset ((S03c7c0ace395d80182db07ae2c30f034), 0, (S7b8b965ad4bca0e41ab51de7b31363a1))
 
#endif
 
#if !defined(macintosh) && !defined(WIN32) && !defined(BEOS)
 
# define S4ed598be2866a6d63878c47ffc2b7d9c close
 
#endif
 Se7cafe837716ad825eb224e3c733ff04::Se7cafe837716ad825eb224e3c733ff04(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, int Safa588e07ba7d2ff20dcab90d97da788): Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ S25e3f9905ddddec8c70ac14736d9ca20 = Safa588e07ba7d2ff20dcab90d97da788; S00ce06fa9365b55a063506933582e5b0 
= false; } Se7cafe837716ad825eb224e3c733ff04::Se7cafe837716ad825eb224e3c733ff04(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Sa6120072b1b1ee42a239c3cf87163151, 
bool S9eb5837a279373ee4cf1d5e6c5f223d8, bool Se6d056471be39d6a77b99dcae00a07a4) : Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(S62390332d50bfebdc49b35c401c29c09(S4d682ec4eed27c53849758bc13b6e179)); 
Se3f1cfcbd2a7460ed4b71f1cadbe52aa = S9eb5837a279373ee4cf1d5e6c5f223d8; S0897acf49c7c1ea9f76efe59187aa046 
= Sc7ab55c385ea800f44b02840bdd351a7; S23113671780610f75a31146b841a132a = Sa6120072b1b1ee42a239c3cf87163151; 
struct sockaddr_in Sc12e01f2a13ff5587e1e9e4aedb8242d; Sc19e6f17145de2e8f33ebc0b4ecd0965((char *) &Sc12e01f2a13ff5587e1e9e4aedb8242d, 
sizeof(Sc12e01f2a13ff5587e1e9e4aedb8242d));  if (S1a857665c83ae96a488ff07a5030fd45(S0897acf49c7c1ea9f76efe59187aa046.c_str())) 
{ Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_family = AF_INET; Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_port= 
htons(S23113671780610f75a31146b841a132a); Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_addr.s_addr = inet_addr(S0897acf49c7c1ea9f76efe59187aa046.c_str()); 
}  else { const char *S3485b4b3d26a626b7f9e9a6eeb0b154f; Saf6c0c3c714d1f5ab0d299b2cbf50060(S3485b4b3d26a626b7f9e9a6eeb0b154f 
= S5e895344675a1d89b0fe9407cd65dffe(S4d682ec4eed27c53849758bc13b6e179, S0897acf49c7c1ea9f76efe59187aa046.c_str())); 
Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_family = AF_INET; Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_port= 
htons(S23113671780610f75a31146b841a132a); Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_addr.s_addr = inet_addr(S3485b4b3d26a626b7f9e9a6eeb0b154f); 
}  if (Se3f1cfcbd2a7460ed4b71f1cadbe52aa) 
#ifdef BEOS
 S25e3f9905ddddec8c70ac14736d9ca20 = socket(AF_INET, SOCK_DGRAM, 0); 
#else
 S25e3f9905ddddec8c70ac14736d9ca20 = socket(PF_INET, SOCK_DGRAM, 0); 
#endif
 else S25e3f9905ddddec8c70ac14736d9ca20 = socket(AF_INET, SOCK_STREAM, 0); if (S25e3f9905ddddec8c70ac14736d9ca20 
< 0) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8(S749d2b576e15d77f0d14f186077e9ace() 
+ "Unable to create socket on port " + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a) + " of hostname " + S0897acf49c7c1ea9f76efe59187aa046); } else return; 
}     int S56bd7107802ebe56c6918992f0608ec6 = connect(S25e3f9905ddddec8c70ac14736d9ca20, (struct sockaddr 
*) &Sc12e01f2a13ff5587e1e9e4aedb8242d, sizeof(Sc12e01f2a13ff5587e1e9e4aedb8242d)); if (S56bd7107802ebe56c6918992f0608ec6 
< 0) { S4ed598be2866a6d63878c47ffc2b7d9c(S25e3f9905ddddec8c70ac14736d9ca20); Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8(S749d2b576e15d77f0d14f186077e9ace() 
+ "Unable to open connection on port " + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a) + " of hostname " + S0897acf49c7c1ea9f76efe59187aa046); } else return; 
} S00ce06fa9365b55a063506933582e5b0 = false; }  bool Se7cafe837716ad825eb224e3c733ff04::Sd0a72a0881be272890b99f92ec69c29f(void) 
{ 
#if 0
 
# define S2179e133ad41f2acaa48810c3f77342d(S9d516be24007bee66989f0fb2cbc369f) \
    do { \
      int Sd96141098636161fc8706ddfc7461643, Sbdeec3607bd133b0e6ecac30f8a5efad; \
    S8bf285ab58cb5ec9d34793b2749b026f S499ac833b3f2bb7e836b8b6a43652a8e ("cld; rep; stosl" \
                          : "=m" (((S911a4bb90127169bff5de458fd511ce6 *) \
                                   (S9d516be24007bee66989f0fb2cbc369f))[Sf8057264e837188061c91c40de20cb57 (Sc47ec3a215dfc45883abef00be3b5f8c)]), \
                            "=&c" (Sd96141098636161fc8706ddfc7461643), "=&D" (Sbdeec3607bd133b0e6ecac30f8a5efad) \
                          : "a" (0), "1" (sizeof (S509f79483ebdbb9036cebe4156fe9831) \
                                          / sizeof (S911a4bb90127169bff5de458fd511ce6)), \
                            "2" ((S911a4bb90127169bff5de458fd511ce6 *) (S9d516be24007bee66989f0fb2cbc369f)) \
                          : "memory"); \
    } while (0)
 
#endif
  fd_set S3d96b95c232789b2901d875f6a48c9f4; struct timeval S90272dda245ae1fb3cf197e91a8689dc; FD_ZERO(&S3d96b95c232789b2901d875f6a48c9f4); 
FD_SET(S25e3f9905ddddec8c70ac14736d9ca20, &S3d96b95c232789b2901d875f6a48c9f4); S90272dda245ae1fb3cf197e91a8689dc.tv_sec 
= 0; S90272dda245ae1fb3cf197e91a8689dc.tv_usec = 0; 
#ifdef S4602e2e429d09bccaaf63ff078b9ea4c
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, (int *) &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#else
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#endif
 if (S020b759adef679a47cb9afe965bb2314 == -1) return false;  if (S020b759adef679a47cb9afe965bb2314 == 
0) return false; else return true; } unsigned long Se7cafe837716ad825eb224e3c733ff04::S4e2021bf4cf7828bbbd067a23d0145ff(unsigned 
char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) {  fd_set 
S3d96b95c232789b2901d875f6a48c9f4; struct timeval S90272dda245ae1fb3cf197e91a8689dc; FD_ZERO(&S3d96b95c232789b2901d875f6a48c9f4); 
FD_SET(S25e3f9905ddddec8c70ac14736d9ca20, &S3d96b95c232789b2901d875f6a48c9f4); S90272dda245ae1fb3cf197e91a8689dc.tv_sec 
= 10; S90272dda245ae1fb3cf197e91a8689dc.tv_usec = 0; Sa2ab70efbfabfbf410aade482c1f565b("Waiting up to 10 seconds for data to appear on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << "...." << endl); 
#ifdef S4602e2e429d09bccaaf63ff078b9ea4c
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, (int *) &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#else
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#endif
 if (S020b759adef679a47cb9afe965bb2314 == 0) { Sa2ab70efbfabfbf410aade482c1f565b("select() timed out waiting for data on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); S3c3931e73423104beed9e0bea06ecd46 = true; return 0; } 
else if (S020b759adef679a47cb9afe965bb2314 < 0) { Sa2ab70efbfabfbf410aade482c1f565b("select() returned error waiting for data on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); return 0; } else if (FD_ISSET(S25e3f9905ddddec8c70ac14736d9ca20, 
&S3d96b95c232789b2901d875f6a48c9f4)) { Sa2ab70efbfabfbf410aade482c1f565b("select() says there is now data available on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << "; reading it" << endl); int Sd871906e18d7e876e6494103da4beebd 
= recv(S25e3f9905ddddec8c70ac14736d9ca20, (char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 
0); Sa2ab70efbfabfbf410aade482c1f565b("Read " << Sd871906e18d7e876e6494103da4beebd << " bytes from socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); if (Sd871906e18d7e876e6494103da4beebd == 0) S00ce06fa9365b55a063506933582e5b0 
= true; return Sd871906e18d7e876e6494103da4beebd; } else { Sa2ab70efbfabfbf410aade482c1f565b("There's data on some other socket in the group?  That's not right." 
<< endl); return 0; } }    unsigned long Se7cafe837716ad825eb224e3c733ff04::Scc7e96e085b9d6b3ef9a1c58a8b2e49a(const 
unsigned char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { 
long Sae887c29c29f5ca22060dcb00e0fb057; Sae887c29c29f5ca22060dcb00e0fb057 = send(S25e3f9905ddddec8c70ac14736d9ca20, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); return Sae887c29c29f5ca22060dcb00e0fb057; 
} void Se7cafe837716ad825eb224e3c733ff04::Sd3d2e617335f08df83599665eef8a418(void) { int S2cb9df9898e55fd0ad829dc202ddbd1c; 
S2cb9df9898e55fd0ad829dc202ddbd1c = S4ed598be2866a6d63878c47ffc2b7d9c(S25e3f9905ddddec8c70ac14736d9ca20); 
open = false; }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S545833936c4079bf95b16d8fea1c7133.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S545833936c4079bf95b16d8fea1c7133.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S8e72db935b8a34033901bc251e070387.h"

#include "Sc9fab33e9458412c527c3fe8a13ee37d.h"

#if Sa06671aa7d7bca0d64f1e6a1a3d29941
 
#if HAVE_STRINGS_H
 
#include <strings.h>

#endif
 
#endif
 
#if HAVE_UNISTD_H
 
#include <unistd.h>

#endif
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#if HAVE_SYS_SOCKET_H
 
#include <sys/socket.h>

#endif
 
#if HAVE_NETINET_IN_H
 
#include <netinet/in.h>

#endif
 
#if S63cf4d813c4c3f398df1ae89db2b63a1
 
#include <fcntl.h>

#endif
 
#if HAVE_SYS_TIME_H
 
#include <sys/time.h>

#endif
 
#if HAVE_NETDB_H
 
#include <netdb.h>

#endif
 
#if HAVE_ARPA_INET_H
 
#include <arpa/inet.h>

#endif
 
#ifdef WIN32
 
# include <winsock.h>

#endif
 
#if !HAS_BZERO
 
#define Sc19e6f17145de2e8f33ebc0b4ecd0965(S03c7c0ace395d80182db07ae2c30f034, S7b8b965ad4bca0e41ab51de7b31363a1)	memset ((S03c7c0ace395d80182db07ae2c30f034), 0, (S7b8b965ad4bca0e41ab51de7b31363a1))
 
#endif
 
#if !defined(macintosh) && !defined(WIN32) && !defined(BEOS)
 
# define S4ed598be2866a6d63878c47ffc2b7d9c close
 
#endif
 Se7cafe837716ad825eb224e3c733ff04::Se7cafe837716ad825eb224e3c733ff04(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, int Safa588e07ba7d2ff20dcab90d97da788): Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ S25e3f9905ddddec8c70ac14736d9ca20 = Safa588e07ba7d2ff20dcab90d97da788; S00ce06fa9365b55a063506933582e5b0 
= false; } Se7cafe837716ad825eb224e3c733ff04::Se7cafe837716ad825eb224e3c733ff04(Se812b5a98988bad1d5b8df118cb6cc7f 
&S8c9a70dc1e604715e475d87430ba602d, const char *Sc7ab55c385ea800f44b02840bdd351a7, unsigned short Sa6120072b1b1ee42a239c3cf87163151, 
bool S9eb5837a279373ee4cf1d5e6c5f223d8, bool Se6d056471be39d6a77b99dcae00a07a4) : Saca418ab700fd41fea0a83282df12687(S8c9a70dc1e604715e475d87430ba602d) 
{ Saf6c0c3c714d1f5ab0d299b2cbf50060(S62390332d50bfebdc49b35c401c29c09(S4d682ec4eed27c53849758bc13b6e179)); 
Se3f1cfcbd2a7460ed4b71f1cadbe52aa = S9eb5837a279373ee4cf1d5e6c5f223d8; S0897acf49c7c1ea9f76efe59187aa046 
= Sc7ab55c385ea800f44b02840bdd351a7; S23113671780610f75a31146b841a132a = Sa6120072b1b1ee42a239c3cf87163151; 
struct sockaddr_in Sc12e01f2a13ff5587e1e9e4aedb8242d; Sc19e6f17145de2e8f33ebc0b4ecd0965((char *) &Sc12e01f2a13ff5587e1e9e4aedb8242d, 
sizeof(Sc12e01f2a13ff5587e1e9e4aedb8242d));  if (S1a857665c83ae96a488ff07a5030fd45(S0897acf49c7c1ea9f76efe59187aa046.c_str())) 
{ Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_family = AF_INET; Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_port= 
htons(S23113671780610f75a31146b841a132a); Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_addr.s_addr = inet_addr(S0897acf49c7c1ea9f76efe59187aa046.c_str()); 
}  else { const char *S3485b4b3d26a626b7f9e9a6eeb0b154f; Saf6c0c3c714d1f5ab0d299b2cbf50060(S3485b4b3d26a626b7f9e9a6eeb0b154f 
= S5e895344675a1d89b0fe9407cd65dffe(S4d682ec4eed27c53849758bc13b6e179, S0897acf49c7c1ea9f76efe59187aa046.c_str())); 
Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_family = AF_INET; Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_port= 
htons(S23113671780610f75a31146b841a132a); Sc12e01f2a13ff5587e1e9e4aedb8242d.sin_addr.s_addr = inet_addr(S3485b4b3d26a626b7f9e9a6eeb0b154f); 
}  if (Se3f1cfcbd2a7460ed4b71f1cadbe52aa) 
#ifdef BEOS
 S25e3f9905ddddec8c70ac14736d9ca20 = socket(AF_INET, SOCK_DGRAM, 0); 
#else
 S25e3f9905ddddec8c70ac14736d9ca20 = socket(PF_INET, SOCK_DGRAM, 0); 
#endif
 else S25e3f9905ddddec8c70ac14736d9ca20 = socket(AF_INET, SOCK_STREAM, 0); if (S25e3f9905ddddec8c70ac14736d9ca20 
< 0) { Scb5e100e5a9a3e7f6d1fd97512215282 = true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8(S749d2b576e15d77f0d14f186077e9ace() 
+ "Unable to create socket on port " + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a) + " of hostname " + S0897acf49c7c1ea9f76efe59187aa046); } else return; 
}     int S56bd7107802ebe56c6918992f0608ec6 = connect(S25e3f9905ddddec8c70ac14736d9ca20, (struct sockaddr 
*) &Sc12e01f2a13ff5587e1e9e4aedb8242d, sizeof(Sc12e01f2a13ff5587e1e9e4aedb8242d)); if (S56bd7107802ebe56c6918992f0608ec6 
< 0) { S4ed598be2866a6d63878c47ffc2b7d9c(S25e3f9905ddddec8c70ac14736d9ca20); Scb5e100e5a9a3e7f6d1fd97512215282 
= true; if (Se6d056471be39d6a77b99dcae00a07a4) { Sdc89a30d4c97fd8b60329797e2883ba8(S749d2b576e15d77f0d14f186077e9ace() 
+ "Unable to open connection on port " + S735ea79b91c0fd264244146d58553488(S4d682ec4eed27c53849758bc13b6e179, 
S23113671780610f75a31146b841a132a) + " of hostname " + S0897acf49c7c1ea9f76efe59187aa046); } else return; 
} S00ce06fa9365b55a063506933582e5b0 = false; }  bool Se7cafe837716ad825eb224e3c733ff04::Sd0a72a0881be272890b99f92ec69c29f(void) 
{ 
#if 0
 
# define S2179e133ad41f2acaa48810c3f77342d(S9d516be24007bee66989f0fb2cbc369f) \
    do { \
      int Sd96141098636161fc8706ddfc7461643, Sbdeec3607bd133b0e6ecac30f8a5efad; \
    S8bf285ab58cb5ec9d34793b2749b026f S499ac833b3f2bb7e836b8b6a43652a8e ("cld; rep; stosl" \
                          : "=m" (((S911a4bb90127169bff5de458fd511ce6 *) \
                                   (S9d516be24007bee66989f0fb2cbc369f))[Sf8057264e837188061c91c40de20cb57 (Sc47ec3a215dfc45883abef00be3b5f8c)]), \
                            "=&c" (Sd96141098636161fc8706ddfc7461643), "=&D" (Sbdeec3607bd133b0e6ecac30f8a5efad) \
                          : "a" (0), "1" (sizeof (S509f79483ebdbb9036cebe4156fe9831) \
                                          / sizeof (S911a4bb90127169bff5de458fd511ce6)), \
                            "2" ((S911a4bb90127169bff5de458fd511ce6 *) (S9d516be24007bee66989f0fb2cbc369f)) \
                          : "memory"); \
    } while (0)
 
#endif
  fd_set S3d96b95c232789b2901d875f6a48c9f4; struct timeval S90272dda245ae1fb3cf197e91a8689dc; FD_ZERO(&S3d96b95c232789b2901d875f6a48c9f4); 
FD_SET(S25e3f9905ddddec8c70ac14736d9ca20, &S3d96b95c232789b2901d875f6a48c9f4); S90272dda245ae1fb3cf197e91a8689dc.tv_sec 
= 0; S90272dda245ae1fb3cf197e91a8689dc.tv_usec = 0; 
#ifdef S4602e2e429d09bccaaf63ff078b9ea4c
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, (int *) &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#else
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#endif
 if (S020b759adef679a47cb9afe965bb2314 == -1) return false;  if (S020b759adef679a47cb9afe965bb2314 == 
0) return false; else return true; } unsigned long Se7cafe837716ad825eb224e3c733ff04::S4e2021bf4cf7828bbbd067a23d0145ff(unsigned 
char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) {  fd_set 
S3d96b95c232789b2901d875f6a48c9f4; struct timeval S90272dda245ae1fb3cf197e91a8689dc; FD_ZERO(&S3d96b95c232789b2901d875f6a48c9f4); 
FD_SET(S25e3f9905ddddec8c70ac14736d9ca20, &S3d96b95c232789b2901d875f6a48c9f4); S90272dda245ae1fb3cf197e91a8689dc.tv_sec 
= 60; S90272dda245ae1fb3cf197e91a8689dc.tv_usec = 0; Sa2ab70efbfabfbf410aade482c1f565b("Waiting up to " 
<< S90272dda245ae1fb3cf197e91a8689dc.tv_sec << " seconds for data to appear on socket " << S25e3f9905ddddec8c70ac14736d9ca20 
<< "...." << endl); 
#ifdef S4602e2e429d09bccaaf63ff078b9ea4c
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, (int *) &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#else
 int S020b759adef679a47cb9afe965bb2314 = select(S25e3f9905ddddec8c70ac14736d9ca20 + 1, &S3d96b95c232789b2901d875f6a48c9f4, 
NULL, NULL, &S90272dda245ae1fb3cf197e91a8689dc); 
#endif
 if (S020b759adef679a47cb9afe965bb2314 == 0) { Sa2ab70efbfabfbf410aade482c1f565b("select() timed out waiting for data on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); S3c3931e73423104beed9e0bea06ecd46 = true; return 0; } 
else if (S020b759adef679a47cb9afe965bb2314 < 0) { Sa2ab70efbfabfbf410aade482c1f565b("select() returned error waiting for data on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); return 0; } else if (FD_ISSET(S25e3f9905ddddec8c70ac14736d9ca20, 
&S3d96b95c232789b2901d875f6a48c9f4)) { Sa2ab70efbfabfbf410aade482c1f565b("select() says there is now data available on socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << "; reading it" << endl); int Sd871906e18d7e876e6494103da4beebd 
= recv(S25e3f9905ddddec8c70ac14736d9ca20, (char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 
0); Sa2ab70efbfabfbf410aade482c1f565b("Read " << Sd871906e18d7e876e6494103da4beebd << " bytes from socket " 
<< S25e3f9905ddddec8c70ac14736d9ca20 << endl); if (Sd871906e18d7e876e6494103da4beebd == 0) S00ce06fa9365b55a063506933582e5b0 
= true; return Sd871906e18d7e876e6494103da4beebd; } else { Sa2ab70efbfabfbf410aade482c1f565b("There's data on some other socket in the group?  That's not right." 
<< endl); return 0; } }    unsigned long Se7cafe837716ad825eb224e3c733ff04::Scc7e96e085b9d6b3ef9a1c58a8b2e49a(const 
unsigned char *S7f2db423a49b305459147332fb01cf87, unsigned long Sf5a8e923f8cd24b56b3bab32358cc58a) { 
long Sae887c29c29f5ca22060dcb00e0fb057; Sae887c29c29f5ca22060dcb00e0fb057 = send(S25e3f9905ddddec8c70ac14736d9ca20, 
(char *) S7f2db423a49b305459147332fb01cf87, Sf5a8e923f8cd24b56b3bab32358cc58a, 0); return Sae887c29c29f5ca22060dcb00e0fb057; 
} void Se7cafe837716ad825eb224e3c733ff04::Sd3d2e617335f08df83599665eef8a418(void) { int S2cb9df9898e55fd0ad829dc202ddbd1c; 
S2cb9df9898e55fd0ad829dc202ddbd1c = S4ed598be2866a6d63878c47ffc2b7d9c(S25e3f9905ddddec8c70ac14736d9ca20); 
open = false; }
